==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/LAYOUTELEMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour LAYOUTELEMENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="LAYOUTELEMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCEPAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCEFIELDID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LAYOUTELEMENTID_Type", propOrder = {
    "sourcepageid",
    "sourcefieldid"
})
public class LAYOUTELEMENTID_Type {

    @XmlElement(name = "SOURCEPAGEID", required = true)
    protected EWSPAGEID_Type sourcepageid;
    @XmlElement(name = "SOURCEFIELDID", required = true)
    protected EWSFIELDID_Type sourcefieldid;

    /**
     * Obtient la valeur de la propriété sourcepageid.
     * 
     * @return
     *     possible object is
     *     {@link EWSPAGEID_Type }
     *     
     */
    public EWSPAGEID_Type getSOURCEPAGEID() {
        return sourcepageid;
    }

    /**
     * Définit la valeur de la propriété sourcepageid.
     * 
     * @param value
     *     allowed object is
     *     {@link EWSPAGEID_Type }
     *     
     */
    public void setSOURCEPAGEID(EWSPAGEID_Type value) {
        this.sourcepageid = value;
    }

    /**
     * Obtient la valeur de la propriété sourcefieldid.
     * 
     * @return
     *     possible object is
     *     {@link EWSFIELDID_Type }
     *     
     */
    public EWSFIELDID_Type getSOURCEFIELDID() {
        return sourcefieldid;
    }

    /**
     * Définit la valeur de la propriété sourcefieldid.
     * 
     * @param value
     *     allowed object is
     *     {@link EWSFIELDID_Type }
     *     
     */
    public void setSOURCEFIELDID(EWSFIELDID_Type value) {
        this.sourcefieldid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/LAYOUTELEMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LAYOUTELEMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LAYOUTELEMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCEPAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCEFIELDID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LAYOUTELEMENTID_Type", propOrder = {
    "sourcepageid",
    "sourcefieldid"
})
public class LAYOUTELEMENTID_Type {

    @XmlElement(name = "SOURCEPAGEID", required = true)
    protected EWSPAGEID_Type sourcepageid;
    @XmlElement(name = "SOURCEFIELDID", required = true)
    protected EWSFIELDID_Type sourcefieldid;

    /**
     * Gets the value of the sourcepageid property.
     * 
     * @return
     *     possible object is
     *     {@link EWSPAGEID_Type }
     *     
     */
    public EWSPAGEID_Type getSOURCEPAGEID() {
        return sourcepageid;
    }

    /**
     * Sets the value of the sourcepageid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EWSPAGEID_Type }
     *     
     */
    public void setSOURCEPAGEID(EWSPAGEID_Type value) {
        this.sourcepageid = value;
    }

    /**
     * Gets the value of the sourcefieldid property.
     * 
     * @return
     *     possible object is
     *     {@link EWSFIELDID_Type }
     *     
     */
    public EWSFIELDID_Type getSOURCEFIELDID() {
        return sourcefieldid;
    }

    /**
     * Sets the value of the sourcefieldid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EWSFIELDID_Type }
     *     
     */
    public void setSOURCEFIELDID(EWSFIELDID_Type value) {
        this.sourcefieldid = value;
    }

}
